@@ -4,6 +4,12 @@ dir.create(tmp, showWarnings = F)
 
 data("test_lib")
 
+tiny_map <- read_extdata("CA_tiny_map.zip") |>
+  read_any() |>
+  conform_spec(range = test_lib$wavenumber,
+               res = NULL) |>
+  process_spec(smooth_intens = T, make_rel = T)
+
 unknown <- read_extdata("ftir_ldpe_soil.asp") |> read_any()
 preproc <- conform_spec(unknown, range = test_lib$wavenumber,
                         res = spec_res(test_lib)) |>
@@ -20,7 +26,9 @@ test_that("match_spec() returns correct structure with AI", {
   get_lib("model", path = tmp)
   lib <- load_lib(type = "model", path = tmp)
 
-  check_OpenSpecy(lib) |> expect_error() |> expect_warning() |> expect_warning() |> expect_warning() |> expect_warning() |> expect_warning()
+  check_OpenSpecy(lib) |>
+    expect_error() |> expect_warning() |> expect_warning() |>
+    expect_warning() |> expect_warning() |> expect_warning()
 
   set.seed(47)
   rn <- runif(n = length(unique(lib$variables_in)))
@@ -52,10 +60,10 @@ test_that("match_spec() returns correct structure", {
 
   nrow(matches) |> expect_equal(5)
   names(matches) |> expect_contains(c("object_id", "library_id", "match_val"))
-  round(matches$match_val, 2) |> expect_equal(c(0.67, 0.57, 0.55, 0.50, 0.43))
+  round(matches$match_val, 2) |> expect_equal(c(0.57, 0.67, 0.55, 0.43, 0.50))
   tolower(matches$polymer) |> expect_equal(
-    c("poly(ethylene)", "polystyrene", "poly(vinyl chloride)",
-      "poly(dimethylsiloxane) (pdms)", NA)
+    c("polystyrene", "poly(ethylene)", "poly(vinyl chloride)", NA,
+      "poly(dimethylsiloxane) (pdms)")
   )
   expect_equal(matches, order)
 })
@@ -104,10 +112,10 @@ test_that("cor_spec() returns a data.table with correct columns", {
 
   nrow(full_test) |> expect_equal(5)
   names(full_test) |> expect_contains(c("object_id", "library_id", "match_val"))
-  round(full_test$match_val, 2) |> expect_equal(c(0.67, 0.57, 0.55, 0.50, 0.43))
+  round(full_test$match_val, 2) |> expect_equal(c(0.57, 0.67, 0.55, 0.43, 0.50))
   tolower(full_test$polymer) |> expect_equal(
-    c("poly(ethylene)", "polystyrene", "poly(vinyl chloride)",
-      "poly(dimethylsiloxane) (pdms)", NA)
+    c("polystyrene", "poly(ethylene)", "poly(vinyl chloride)", NA,
+      "poly(dimethylsiloxane) (pdms)")
   )
 })
 
@@ -115,6 +123,19 @@ test_that("filter_spec() handles input errors correctly", {
   filter_spec(1:1000) |> expect_error()
 })
 
+test_that("Test that raman hdpe accurately identified", {
+  proc_rhdpe <- process_spec(raman_hdpe,conform_spec = T,
+                             conform_spec_args = list(range = test_lib$wavenumber,
+                                                      res = NULL,
+                                                      type = "interp"))
+
+  check <- match_spec(proc_rhdpe, test_lib, top_n = 1,
+                      add_library_metadata = "sample_name")
+
+  expect_identical(round(check$match_val, 3), 0.974)
+  expect_identical(check$polymer_class, "Polyolefins (POLYALKENES)")
+})
+
 # Write the tests for filter_spec function
 test_that("filter_spec() returns erroneous OpenSpecy object when removing all spectra", {
   os_filtered <- filter_spec(test_lib, logic = rep(F, ncol(test_lib$spectra))) |>
@@ -141,5 +162,13 @@ test_that("get_metadata() handles input errors correctly", {
   get_metadata(1:1000) |> expect_error()
 })
 
+test_that("cor_spec() routine and match_spec() return same values", {
+  cors <- cor_spec(tiny_map, test_lib)
+  max_correlations <- max_cor_named(cors)
+  names <- max_correlations |> sort(decreasing = T) |> names()
+  top_matches <- match_spec(x = tiny_map, library = test_lib, top_n = 1)
+  expect_identical(names, top_matches$library_id)
+})
+
 # Tidy up
 unlink(tmp, recursive = T)
