@@ -1,5 +1,5 @@
 data("raman_hdpe")
 
 test_that("spec_res() gives correct output", {
-  expect_equal(round(spec_res(raman_hdpe$wavenumber), 3), 3.005)
+  spec_res(raman_hdpe$wavenumber) |> round(2) |> expect_equal(2.54)
 })
